@@ -1,6 +1,5 @@
 graphe.erreurs.calculer <-
 function(variable,facteur1,facteur2=NULL,valeurs=NULL,prop.nvx=NULL) {
-  alert=FALSE
   erreur.inf<-NULL
   erreur.sup<-NULL
   if (tclvalue(Env$l.var$moyprop)=="moy") {
@@ -12,16 +11,8 @@ function(variable,facteur1,facteur2=NULL,valeurs=NULL,prop.nvx=NULL) {
 	  erreur<-tapply(variable,facteur1,function(x) sd(x,na.rm=TRUE)/sqrt(length(na.omit(x))))
 	  erreur.inf<-erreur.sup<-erreur
 	} else if (tclvalue(Env$l.var$erreur)==Env$voc[98,1]) {
-	  test<-tapply(variable,facteur1,function(x) length(na.omit(x)))
-	  if (any(test<20)) {
-	    medianes<-tapply(variable,facteur1,function(x) median(x,na.rm=TRUE))
-	    erreur.inf<-medianes-tapply(variable,facteur1,function(x) wilcox.test(x,conf.int=TRUE)$conf.int[1])
-	    erreur.sup<-tapply(variable,facteur1,function(x) wilcox.test(x,conf.int=TRUE)$conf.int[2])-medianes
-	    alert<-TRUE
-	  } else {
-	    moyennes<-tapply(variable,facteur1,function(x) mean(x,na.rm=TRUE))
-	    erreur.inf<-erreur.sup<-moyennes-tapply(variable,facteur1,function(x) t.test(x)$conf.int[1])
-	  }
+	  moyennes<-tapply(variable,facteur1,function(x) mean(x,na.rm=TRUE))
+	  erreur.inf<-erreur.sup<-moyennes-tapply(variable,facteur1,function(x) t.test(x)$conf.int[1])
 	} else {
 	  erreur.inf<-erreur.sup<-rep(0,nlevels(facteur1))
 	}
@@ -33,16 +24,8 @@ function(variable,facteur1,facteur2=NULL,valeurs=NULL,prop.nvx=NULL) {
 	  erreur<-tapply(variable,list(facteur2,facteur1),function(x) sd(x,na.rm=TRUE)/sqrt(length(na.omit(x))))
 	  erreur.inf<-erreur.sup<-erreur
 	} else if (tclvalue(Env$l.var$erreur)==Env$voc[98,1]) {
-	  test<-tapply(variable,list(facteur2,facteur1),function(x) length(na.omit(x)))
-	  if (any(test<20)) {
-	    medianes<-tapply(variable,list(facteur2,facteur1),function(x) median(x,na.rm=TRUE))
-	    erreur.inf<-medianes-tapply(variable,list(facteur2,facteur1),function(x) wilcox.test(x,conf.int=TRUE)$conf.int[1])
-	    erreur.sup<-tapply(variable,list(facteur2,facteur1),function(x) wilcox.test(x,conf.int=TRUE)$conf.int[2])-medianes
-	    alert<-TRUE
-	  } else {
-	    moyennes<-tapply(variable,list(facteur2,facteur1),function(x) mean(x,na.rm=TRUE))
-	    erreur.inf<-erreur.sup<-moyennes-tapply(variable,list(facteur2,facteur1),function(x) t.test(x)$conf.int[1])
-	  }
+	  moyennes<-tapply(variable,list(facteur2,facteur1),function(x) mean(x,na.rm=TRUE))
+	  erreur.inf<-erreur.sup<-moyennes-tapply(variable,list(facteur2,facteur1),function(x) t.test(x)$conf.int[1])
 	} else {
 	  erreur.inf<-erreur.sup<-matrix(0,ncol=nlevels(facteur1),nrow=nlevels(facteur2))
 	}
@@ -88,5 +71,5 @@ function(variable,facteur1,facteur2=NULL,valeurs=NULL,prop.nvx=NULL) {
 	}
     }
   }
-  return(list(erreur.inf=erreur.inf,erreur.sup=erreur.sup,alert=alert))
+  return(list(erreur.inf=erreur.inf,erreur.sup=erreur.sup))
 }
\ No newline at end of file
