@@ -39,6 +39,17 @@ function() {
 	text(as.numeric(tclvalue(Env$l.var$add.param1)),as.numeric(tclvalue(Env$l.var$add.param2)),
 	  labels=tclvalue(Env$l.var$add.txt),cex=as.numeric(tclvalue(Env$l.var$add.epaisseur1)),
 	  col=tclvalue(Env$l.var$add.col1))
+	if (Env$l.code$save==TRUE) {
+	  sink(file=file.path(Env$l.code$folder,paste(paste("GrapheR",paste(strsplit(as.character(Sys.Date()),split="-")[[1]],collapse="."),
+	    sep="-"),".R",sep=""),fsep=.Platform$file.sep),append=TRUE)
+	  cat("# Added: text\n\n")
+	  texte<-paste("text(",tclvalue(Env$l.var$add.param1),", ",tclvalue(Env$l.var$add.param2),sep="")
+	  texte<-paste(texte,", labels=\"",tclvalue(Env$l.var$add.txt),"\"",sep="")
+	  if (tclvalue(Env$l.var$add.col1)!="black" & tclvalue(Env$l.var$add.col1)!="#000000") {texte<-paste(texte,", col=\"",tclvalue(Env$l.var$add.col1),"\"",sep="")}
+	  texte<-paste(texte,", cex=",tclvalue(Env$l.var$add.epaisseur1),")\n\n",sep="")
+	  cat(texte)
+	  sink(NULL)
+	}
     } else {
 	msg(text=Env$voc[163,1],type="error")
     }
